package com.zhyc.module.dairyProducts.mapper;

import java.util.List;
import com.zhyc.module.dairyProducts.domain.NpFreshMilkInsp;
import org.apache.ibatis.annotations.Mapper;

/**
 * 鲜奶生产，成品检验记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-18
 */
@Mapper
public interface NpFreshMilkInspMapper 
{
    /**
     * 查询鲜奶生产，成品检验记录
     * 
     * @param id 鲜奶生产，成品检验记录主键
     * @return 鲜奶生产，成品检验记录
     */
    public NpFreshMilkInsp selectNpFreshMilkInspById(Long id);

    /**
     * 查询鲜奶生产，成品检验记录列表
     * 
     * @param npFreshMilkInsp 鲜奶生产，成品检验记录
     * @return 鲜奶生产，成品检验记录集合
     */
    public List<NpFreshMilkInsp> selectNpFreshMilkInspList(NpFreshMilkInsp npFreshMilkInsp);

    /**
     * 新增鲜奶生产，成品检验记录
     * 
     * @param npFreshMilkInsp 鲜奶生产，成品检验记录
     * @return 结果
     */
    public int insertNpFreshMilkInsp(NpFreshMilkInsp npFreshMilkInsp);

    /**
     * 修改鲜奶生产，成品检验记录
     * 
     * @param npFreshMilkInsp 鲜奶生产，成品检验记录
     * @return 结果
     */
    public int updateNpFreshMilkInsp(NpFreshMilkInsp npFreshMilkInsp);

    /**
     * 删除鲜奶生产，成品检验记录
     * 
     * @param id 鲜奶生产，成品检验记录主键
     * @return 结果
     */
    public int deleteNpFreshMilkInspById(Long id);

    /**
     * 批量删除鲜奶生产，成品检验记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNpFreshMilkInspByIds(Long[] ids);
}
